@@ -19,28 +19,28 @@
  */
 
 #include "box_reports.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Box_Reports::Box_Reports(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Box_DB_Table(cobject, refGlade),
+Box_Reports::Box_Reports(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Box_DB_Table(cobject, builder),
   m_pLabelFrameTitle(0),
   m_colReportName(0),
   m_colTitle(0)
 {
   //Get the Glade-instantiated widgets, and connect signal handlers:
   Gtk::Button* pButtonCancel = 0;
-  refGlade->get_widget("button_cancel", pButtonCancel);
+  builder->get_widget("button_cancel", pButtonCancel);
   set_button_cancel(*pButtonCancel);
 
   Gtk::Alignment* pAligmentPlaceholder = 0;
-  refGlade->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
+  builder->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
   pAligmentPlaceholder->add(m_AddDel);
 
-  //refGlade->get_widget("label_frame_title", m_pLabelFrameTitle);
+  //builder->get_widget("label_frame_title", m_pLabelFrameTitle);
 
   m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_Reports::on_adddel_Add));
   m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_Reports::on_adddel_Delete));
@@ -67,7 +67,7 @@ void Box_Reports::fill_row(const Gtk::TreeModel::iterator& iter, const sharedptr
 
 bool Box_Reports::fill_from_database()
 {
-  Bakery::BusyCursor busy_cursor(get_app_window());
+  BusyCursor busy_cursor(get_app_window());
 
   bool result = Box_DB_Table::fill_from_database();
 
@@ -97,12 +97,12 @@ bool Box_Reports::fill_from_database()
   //Glib::ustring strTitle = Glib::ustring("<b>") + _("Tables from Database: ") + get_database_name() + "");
   //m_pLabelFrameTitle->set_markup(strTitle);
 
-  Document_Glom::type_listReports listTableReports;
-  Document_Glom* document = get_document();
+  Document::type_listReports listTableReports;
+  Document* document = get_document();
   if(document)
   {
     listTableReports = document->get_report_names(m_table_name);
-    for(Document_Glom::type_listReports::const_iterator iter = listTableReports.begin(); iter != listTableReports.end(); ++iter)
+    for(Document::type_listReports::const_iterator iter = listTableReports.begin(); iter != listTableReports.end(); ++iter)
     {
       sharedptr<Report> report = document->get_report(m_table_name, *iter);
       if(report)
@@ -133,6 +133,16 @@ void Box_Reports::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     report->set_name(report_name);
     m_AddDel.set_value_key(row, report_name);
 
+    //Set a suitable starting title, if there is none already:
+    Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
+    if(title.empty())
+    {
+      title = Utils::title_from_string(report_name);
+      m_AddDel.set_value(row, m_colTitle, title);
+    }
+
+    report->set_title(title);
+
     get_document()->set_report(m_table_name, report);
   }
 }
@@ -151,7 +161,7 @@ void Box_Reports::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring report_name = m_AddDel.get_value_key(row);
 
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
      save_to_document();
@@ -161,12 +171,13 @@ void Box_Reports::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
   }
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Reports::save_to_document()
 {
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     //Add any reports that are not in the document:
-    Document_Glom::type_listReports listReports = get_document()->get_report_names(m_table_name);
+    Document::type_listReports listReports = get_document()->get_report_names(m_table_name);
 
     bool modified = false;
     for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
@@ -189,13 +200,14 @@ void Box_Reports::save_to_document()
      get_document()->set_modified(true);
   }
 }
+#endif //GLOM_ENABLE_CLIENT_ONLY
 
 void Box_Reports::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column)
 {
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     const Glib::ustring report_name = m_AddDel.get_value_key(row);
-    Document_Glom* document = get_document();
+    Document* document = get_document();
 
     sharedptr<Report> report = document->get_report(m_table_name, report_name);
     if(report)
