@@ -24,11 +24,16 @@
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm/frame.h>
-#include "bakery/View/View_Composite.h"
-#include <glom/libglom/document/document_glom.h>
+#include <gtkmm/toggleaction.h>
+#include <libglom/document/bakery/view/view_composite.h>
+#include <libglom/document/document.h>
 
-#include "dialog_glom.h"
+#include "window_boxholder.h"
+
+#ifndef GLOM_ENABLE_MAEMO
 #include "navigation/box_tables.h"
+#endif
+
 #include "mode_data/notebook_data.h"
 #include "mode_find/notebook_find.h"
 
@@ -40,7 +45,7 @@
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 #include "dialog_connection.h"
-#include <glom/libglom/utils.h>
+#include <libglom/utils.h>
 
 #include "mode_data/box_data_list_related.h" //only for m_HackToFixLinkerError.
 
@@ -54,18 +59,21 @@ class Dialog_AddRelatedTable;
 class Dialog_RelationshipsOverview;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+class Dialog_ProgressCreating; //TODO: Rename this because it's not just about creating databases.
+
 class Frame_Glom :
   public PlaceHolder,
-  //public Bakery::View_Composite<Document_Glom>,
+  //public GlomBakery::View_Composite<Document>,
   public Base_DB //Inherits from View_Composite.
 {
 public: 
-  Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Frame_Glom();
 
   void set_databases_selected(const Glib::ustring& strName);
 
   void on_box_tables_selected(const Glib::ustring& strName);
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_box_reports_selected(const Glib::ustring& strName);
   void on_box_print_layouts_selected(const Glib::ustring& strName);
@@ -76,13 +84,18 @@ public:
   void on_menu_file_export();
   void on_menu_file_import();
   void on_menu_file_print_edit_layouts();
-
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  void on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>& action);
   void on_menu_file_print();
 
   void on_menu_Mode_Data();
   void on_menu_Mode_Find();
-
+  
+  #ifdef GLOM_ENABLE_MAEMO
+  void on_menu_add_record();
+  #endif
+  
   void on_menu_report_selected(const Glib::ustring& report_name);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -127,7 +140,7 @@ public:
 
   void on_dialog_tables_hide();
 
-  virtual void set_document(Document_Glom* pDocument); //View override
+  virtual void set_document(Document* pDocument); //View override
   virtual void load_from_document(); //View override
 
   enum enumModes
@@ -141,25 +154,28 @@ public:
 
   static void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type = Gtk::MESSAGE_INFO);
 
-  //Show the dialog to request the password, and check whether it works.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool connection_request_password_and_attempt(const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring());
-#else
-  bool connection_request_password_and_attempt(const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring(), std::auto_ptr<ExceptionConnection>& error);
-#endif
+  /** Show the dialog to request the password, and check whether it works.
+   *
+   * @param database_not_found true if the connection failed only because the database was not found on the server.
+   * @param known_username The username if known. Otherwise, the user will be asked via a dialog.
+   * @param known_password The password if known. Otherwise, the user will be asked via a dialog.
+   * @param confirm_existing_user If true then an alternative message text will be shown.
+   * @result true if the connection succeeded and the database was found on the server.
+   */
+  bool connection_request_password_and_attempt(bool& database_not_found, const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring(), bool confirm_existing_user = false);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Show the dialog to request the password, and choose an unused database name.
   bool connection_request_password_and_choose_new_database_name();
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
   ///Create the database for new documents, showing the Connection dialog
   bool create_database(const Glib::ustring& database_name, const Glib::ustring& title);
   void show_layout_toolbar(bool show = true);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  void export_data_to_vector(Document_Glom::type_example_rows& the_vector, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
-  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
-  void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
+  void export_data_to_vector(Document::type_example_rows& the_vector, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
+  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
+  void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
 
   /** Show the table again. For instance, if the document has changed, or we want to display it differently.
    */
@@ -168,9 +184,13 @@ public:
   ///Whether we are viewing the details or list.
   bool get_viewing_details() const;
 
+  Glib::ustring get_shown_table_name() const;
+
 protected:
 
-  //virtual void set_document(Document_Glom* pDocument); //override
+  
+
+  //virtual void set_document(Document* pDocument); //override
 
   /** Show the table, possibly selecting a particular record, possibly showing that in the details tab. This allows table_name to be empty in which case no
    * table will be shown.
@@ -192,14 +212,18 @@ protected:
   void show_no_table();
 
   void show_table_title();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+  bool connection_request_initial_password(Glib::ustring& user, Glib::ustring& password);
+
   void update_table_in_document_from_database();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-  virtual void set_mode_widget(Gtk::Widget& widget); //e.g. show the design mode notebook.
-  virtual bool set_mode(enumModes mode); //bool indicates that there was a change.
 
-  virtual Gtk::Window* get_app_window();
-  virtual const Gtk::Window* get_app_window() const;
+  void set_mode_widget(Gtk::Widget& widget); //e.g. show the design mode notebook.
+  bool set_mode(enumModes mode); //bool indicates that there was a change.
+
+  Gtk::Window* get_app_window();
+  const Gtk::Window* get_app_window() const;
 
   void update_records_count();
 
@@ -217,19 +241,29 @@ protected:
   void on_dialog_add_related_table_response(int response);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  void on_connection_initialize_progress();
+  void on_connection_startup_progress();
+  void on_connection_cleanup_progress();
+  void cleanup_connection();
+  bool handle_connection_initialize_errors(ConnectionPool::InitErrors error);
+
+private:
+
+  /**
+   * @result Whether to try again.
+   */
+  bool handle_request_password_connection_error(bool asked_for_password, const ExceptionConnection& ex, bool& database_not_found);
+  
   //Member data:
   Glib::ustring m_table_name;
 
   //Child widgets:
   Gtk::Label* m_pLabel_Table;
+  Gtk::HBox* m_box_header;
   Gtk::HBox* m_box_footer;
   Gtk::Label* m_pLabel_Mode;
   Gtk::Label* m_pLabel_userlevel;
 
-  Gtk::HBox* m_pBox_QuickFind; //Only show this when in Find mode.
-  Gtk::Entry* m_pEntry_QuickFind;
-  Gtk::Button* m_pButton_QuickFind;
-
   Gtk::HBox* m_pBox_RecordsCount; //Only show this when in Data mode.
   Gtk::Label* m_pLabel_RecordsCount;
   Gtk::Label* m_pLabel_FoundCount;
@@ -237,21 +271,30 @@ protected:
 
   PlaceHolder* m_pBox_Mode; //Contains e.g. design mode notebook.
 
+#ifndef GLOM_ENABLE_MAEMO
+  //Navigation:
   Box_Tables* m_pBox_Tables;
+  Window_BoxHolder* m_pDialog_Tables;
+#endif //GLOM_ENABLE_MAEMO
 
   Notebook_Data m_Notebook_Data;
+  
+  Gtk::HBox* m_pBox_QuickFind; //Only show this when in Find mode.
+  Gtk::Entry* m_pEntry_QuickFind;
+  Gtk::Button* m_pButton_QuickFind;
   Notebook_Find m_Notebook_Find;
-
-  //Navigation:
-  Dialog_Glom* m_pDialog_Tables;
-
+  
+  #ifdef GLOM_ENABLE_MAEMO
+  Hildon::StackableWindow m_maemo_window_find;
+  #endif
+  
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Developer:
-  Dialog_Glom* m_pDialog_Reports;
+  Window_BoxHolder* m_pDialog_Reports;
   Dialog_Layout_Report* m_pDialogLayoutReport;
   Box_Reports* m_pBox_Reports;
   
-  Dialog_Glom* m_pDialog_PrintLayouts;
+  Window_BoxHolder* m_pDialog_PrintLayouts;
   Window_PrintLayout_Edit* m_pDialogLayoutPrint;
   Box_Print_Layouts* m_pBox_PrintLayouts;
 
@@ -259,8 +302,12 @@ protected:
   Dialog_Relationships* m_pDialog_Relationships;
   Dialog_AddRelatedTable* m_dialog_addrelatedtable;
   Dialog_RelationshipsOverview* m_dialog_relationships_overview;
-  
-#endif // !GLOM_ENABLE_CLIENT_ONLY
+    
+  Dialog_ProgressCreating* m_dialog_progess_connection_initialize;
+#endif //GLOM_ENABLE_CLIENT_ONLY
+
+  Dialog_ProgressCreating* m_dialog_progess_connection_startup;
+  Dialog_ProgressCreating* m_dialog_progess_connection_cleanup;
 
   Dialog_Connection* m_pDialogConnection;
 };
