@@ -42,115 +42,6 @@ static EpcProtocol publish_protocol = EPC_PROTOCOL_HTTPS;
 // Uncomment to see debug messages
 //#define GLOM_CONNECTION_DEBUG
 
-namespace
-{
-
-#ifdef G_OS_WIN32
-static BOOL
-pgwin32_get_dynamic_tokeninfo(HANDLE token, TOKEN_INFORMATION_CLASS class_,
-                char **InfoBuffer, char *errbuf, int errsize)
-{
-  DWORD    InfoBufferSize;
-
-  if(GetTokenInformation(token, class_, NULL, 0, &InfoBufferSize))
-  {
-    snprintf(errbuf, errsize, "could not get token information: got zero size\n");
-    return FALSE;
-  }
-
-  if(GetLastError() != ERROR_INSUFFICIENT_BUFFER)
-  {
-    snprintf(errbuf, errsize, "could not get token information: error code %d\n",
-         (int) GetLastError());
-    return FALSE;
-  }
-
-  *InfoBuffer = static_cast<char*>(malloc(InfoBufferSize));
-  if(*InfoBuffer == NULL)
-  {
-    snprintf(errbuf, errsize, "could not allocate %d bytes for token information\n",
-         (int) InfoBufferSize);
-    return FALSE;
-  }
-
-  if(!GetTokenInformation(token, class_, *InfoBuffer,
-               InfoBufferSize, &InfoBufferSize))
-  {
-    snprintf(errbuf, errsize, "could not get token information: error code %d\n",
-         (int) GetLastError());
-    return FALSE;
-  }
-
-  return TRUE;
-}
-
-int
-pgwin32_is_admin(void)
-{
-  HANDLE    AccessToken;
-  char     *InfoBuffer = NULL;
-  char    errbuf[256];
-  PTOKEN_GROUPS Groups;
-  PSID    AdministratorsSid;
-  PSID    PowerUsersSid;
-  SID_IDENTIFIER_AUTHORITY NtAuthority = {SECURITY_NT_AUTHORITY};
-  UINT    x;
-  BOOL    success;
-
-  if(!OpenProcessToken(GetCurrentProcess(), TOKEN_READ, &AccessToken))
-  {
-    throw std::runtime_error(Glib::ustring::compose("Could not open process token: error code %1", (int)GetLastError()));
-  }
-
-  if(!pgwin32_get_dynamic_tokeninfo(AccessToken, TokenGroups,
-                     &InfoBuffer, errbuf, sizeof(errbuf)))
-  {
-    CloseHandle(AccessToken);
-    throw std::runtime_error(errbuf);
-  }
-
-  Groups = (PTOKEN_GROUPS) InfoBuffer;
-
-  CloseHandle(AccessToken);
-
-  if(!AllocateAndInitializeSid(&NtAuthority, 2,
-     SECURITY_BUILTIN_DOMAIN_RID, DOMAIN_ALIAS_RID_ADMINS, 0, 0, 0, 0, 0,
-                  0, &AdministratorsSid))
-  {
-    free(InfoBuffer);
-    throw std::runtime_error(Glib::ustring::compose("could not get SID for Administrators group: error code %1", (int)GetLastError()));
-  }
-
-  if(!AllocateAndInitializeSid(&NtAuthority, 2,
-  SECURITY_BUILTIN_DOMAIN_RID, DOMAIN_ALIAS_RID_POWER_USERS, 0, 0, 0, 0, 0,
-                  0, &PowerUsersSid))
-  {
-    free(InfoBuffer);
-    FreeSid(AdministratorsSid);
-    throw std::runtime_error(Glib::ustring::compose("could not get SID for PowerUsers group: error code %1", (int) GetLastError()));
-  }
-
-  success = FALSE;
-
-  for (x = 0; x < Groups->GroupCount; x++)
-  {
-    if((EqualSid(AdministratorsSid, Groups->Groups[x].Sid) && (Groups->Groups[x].Attributes & SE_GROUP_ENABLED)) ||
-      (EqualSid(PowerUsersSid, Groups->Groups[x].Sid) && (Groups->Groups[x].Attributes & SE_GROUP_ENABLED)))
-    {
-      success = TRUE;
-      break;
-    }
-  }
-
-  free(InfoBuffer);
-  FreeSid(AdministratorsSid);
-  FreeSid(PowerUsersSid);
-  return success;
-}
-
-#endif // G_OS_WIN32
-} // anonymous namespace
-
 namespace Glom
 {
 
@@ -585,7 +476,7 @@ bool ConnectionPool::handle_error_cerr_only()
         if(event && (event->get_event_type() == Gnome::Gda::CONNECTION_EVENT_ERROR))
         {
           if(!error_details.empty())
-            error_details += "\n"; //Add newline after each error.
+            error_details += '\n'; //Add newline after each error.
 
           error_details += (*iter)->get_description();
           std::cerr << "Internal error (Database): " << error_details << std::endl;
@@ -859,18 +750,18 @@ EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* pu
 //static
 gboolean ConnectionPool::on_publisher_document_authentication(EpcAuthContext* context, const gchar* user_name, gpointer user_data)
 {
-  g_return_val_if_fail(context, FALSE);
+  g_return_val_if_fail(context, false);
 
   ConnectionPool* connection_pool = (ConnectionPool*)(user_data);
-  g_return_val_if_fail(connection_pool, FALSE);
+  g_return_val_if_fail(connection_pool, false);
 
   // Check if the username/password are correct:
   const gchar* password = epc_auth_context_get_password(context);
-  g_return_val_if_fail(password, FALSE); //TODO: This seems to happen once before this callback is called again properly.
+  g_return_val_if_fail(password, false); //TODO: This seems to happen once before this callback is called again properly.
 
   //std::cout << "ConnectionPool::on_publisher_document_authentication(): username=" << user_name << ", password=" << password << std::endl;
 
-  g_return_val_if_fail(connection_pool->m_backend.get(), FALSE);
+  g_return_val_if_fail(connection_pool->m_backend.get(), false);
  
   //Attempt a connection with this username/password:
   std::auto_ptr<ExceptionConnection> error;
@@ -942,22 +833,22 @@ void ConnectionPool::avahi_start_publishing()
   if(!document)
     return;
 
-  m_epc_publisher = epc_publisher_new(document->get_database_title().c_str(), "glom", NULL);
+  m_epc_publisher = epc_publisher_new(document->get_database_title().c_str(), "glom", 0);
   epc_publisher_set_protocol(m_epc_publisher, publish_protocol);
   
-  epc_publisher_add_handler(m_epc_publisher, "document", on_publisher_document_requested, this /* user_data */, NULL);
+  epc_publisher_add_handler(m_epc_publisher, "document", on_publisher_document_requested, this /* user_data */, 0);
 
   //Password-protect the document,
   //because the document's structure could be considered as a business secret:
   epc_publisher_set_auth_flags(m_epc_publisher, EPC_AUTH_PASSWORD_TEXT_NEEDED);
-  epc_publisher_set_auth_handler(m_epc_publisher, "document", on_publisher_document_authentication, this /* user_data */, NULL);
+  epc_publisher_set_auth_handler(m_epc_publisher, "document", on_publisher_document_authentication, this /* user_data */, 0);
 
   //Install progress callback, so we can keep the UI responsive while libepc is generating certificates for the first time:
   EpcShellProgressHooks callbacks;
   callbacks.begin = &ConnectionPool::on_epc_progress_begin;
   callbacks.update = &ConnectionPool::on_epc_progress_update;
   callbacks.end = &ConnectionPool::on_epc_progress_end;
-  epc_shell_set_progress_hooks(&callbacks, this, NULL);
+  epc_shell_set_progress_hooks(&callbacks, this, 0);
       
   //Prevent the consumer from seeing duplicates,
   //if multiple client computers advertize the same document:
