@@ -21,7 +21,7 @@
 #include "fieldtypes.h"
 #include <iostream> //For debug output
 #include <libgda/gda-util.h> // For gda_g_type_to_string
-#include <glom/libglom/connectionpool.h>
+#include <libglom/connectionpool.h>
 
 namespace Glom
 {
@@ -49,7 +49,7 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
       data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES);
 #else
     std::auto_ptr<Glib::Error> error;
-    if(gda_connection->update_meta_store(error))
+    if(true) //Already done in ConnectionPool::connect(): gda_connection->update_meta_store(error))
       data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES, error);
 
     // Ignore error here, we do not process data_model_tables if it is NULL
@@ -71,7 +71,11 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
 
       for(int i = 0; i < rows; ++i)
       {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
         const Gnome::Gda::Value value_name = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_NAME, i);
+#else
+        const Gnome::Gda::Value value_name = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_NAME, i, error);
+#endif
 
         //Get the types's string representation:
         Glib::ustring schema_type_string;
@@ -80,7 +84,11 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
         
         if(!schema_type_string.empty())
         {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
           Gnome::Gda::Value value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i);
+#else
+          Gnome::Gda::Value value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i, error);
+#endif
           if(value_gdatype.get_value_type() == G_TYPE_STRING)
           {
             Glib::ustring type_string = value_gdatype.get_string();
