@@ -19,15 +19,12 @@
  */
 
 
-#include "config.h" // For HAVE_STRPTIME
-
-#include <libgda/gda-blob-op.h> // For gda_blob_op_read_all()
+#include <libglom/libglom_config.h> // For HAVE_STRPTIME
 
 #include "glomconversions.h"
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/utils.h>
-#include <gdkmm/pixbufloader.h>
-#include <glom/libglom/data_structure/layout/layoutitem_image.h> // For GLOM_IMAGE_FORMAT
+#include <libglom/connectionpool.h>
+#include <libglom/utils.h>
+
 #include <glibmm/i18n.h>
 #include <sstream> //For stringstream
 
@@ -58,9 +55,12 @@ namespace
 namespace Glom
 {
 
-// Increase the number of digits (even before the decimal point) we can 
-// have until it uses the awkward e syntax. The default seems to be 7
-static const int STRINGSTREAM_PRECISION_DEFAULT = 15;
+
+int Conversions::get_stringstream_precision_default()
+{
+    static const int stringstream_precision_default = 15;
+    return stringstream_precision_default;
+}
 
 Glib::ustring Conversions::format_time(const tm& tm_data)
 {
@@ -99,7 +99,7 @@ static inline const char* glom_get_locale_date_format()
      * and default to %d/%m/%Y" if it detects a problem, but that might not be 
      * correct for your locale.
      * Thanks.
-     */
+     * xgettext:no-c-format */
     c_locale_date_format = _("%x");
   }
 
@@ -157,7 +157,7 @@ bool Conversions::sanity_check_date_parsing()
   return true;
 }
 
-bool Conversions::sanity_check_date_text_representation_uses_4_digit_years()
+bool Conversions::sanity_check_date_text_representation_uses_4_digit_years(bool debug_output)
 {
   //A date that is really really the date that we mean:
   tm the_c_time;
@@ -170,7 +170,9 @@ bool Conversions::sanity_check_date_text_representation_uses_4_digit_years()
 
   //Get the current locale's text representation:
   const Glib::ustring date_text = format_date(the_c_time);
-  std::cout << "DEBUG: 22nd November 2008 in this locale has this text represention: " << date_text << std::endl;
+
+  if(debug_output)
+    std::cout << "DEBUG: 22nd November 2008 in this locale has this text represention: " << date_text << std::endl;
 
   //See if the year appears in full in that date.
   //There are probably some locales for which this fails.
@@ -179,7 +181,7 @@ bool Conversions::sanity_check_date_text_representation_uses_4_digit_years()
   if(pos == Glib::ustring::npos)
   {
     //Note to translators: If you see this error in the terminal at startup then you need to translate the %x elsewhere.
-    std::cerr << _("ERROR: sanity_check_date_text_represenation_uses_4_digit_year(): Sanity check failed: Glom does not seem to use 4 digits to display years in a date's text representation, in this locale. Defaulting to dd/mm/yyyy though this might be incorrect for your locale. This needs attention from a translator. Please file a bug - see http://www.glom.org") << std::endl;
+    std::cerr << _("ERROR: sanity_check_date_text_representation_uses_4_digit_year(): Sanity check failed: Glom does not seem to use 4 digits to display years in a date's text representation, in this locale. Defaulting to dd/mm/yyyy though this might be incorrect for your locale. This needs attention from a translator. Please file a bug - see http://www.glom.org") << std::endl;
 
     //Do not depend on translators to do what we ask.
     //Default to a common format, though this would be incorrect in some 
@@ -432,12 +434,21 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       {
         //Increase the number of digits (even before the decimal point) we can 
         //have until it uses the awkward e syntax. The default seems to be 7.
-        another_stream << std::setprecision(STRINGSTREAM_PRECISION_DEFAULT);
+        another_stream << std::setprecision( NumericFormat::get_default_precision() );
       }
 
       if(!(numeric_format.m_currency_symbol.empty()))
       {
-        another_stream << numeric_format.m_currency_symbol << " ";
+        std::string charset;
+        Glib::get_charset(charset);
+        Glib::ustring currency_symbol = Glib::convert_with_fallback(numeric_format.m_currency_symbol, charset, "UTF-8");
+        // Uses convert_with_fallback(.) for the curreny symbol to avoid an
+        // exception where the operator<<'s automatic conversion fails.
+        // Incompatible encodings are possible since the currency symbol itself
+        // is stored in the Glom document (UTF-8), whereas the stream encoding
+        // depends on the user's locale (needed for the numeric value
+        // representation).
+        another_stream << currency_symbol << " ";
       }
     }
 
@@ -594,7 +605,9 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
 
     std::stringstream clocale_stream;
     clocale_stream.imbue( std::locale::classic() ); //The C locale.
-    clocale_stream << std::setprecision(STRINGSTREAM_PRECISION_DEFAULT); //Avoid the e syntax. Normally this happens afer 7 digits, with loss of precision. TODO: Handle more.
+
+    //Avoid the e syntax. Normally this happens afer 7 digits, with loss of precision. TODO: Handle more.
+    clocale_stream << std::setprecision( NumericFormat::get_default_precision() );
     clocale_stream << the_number;
     const Glib::ustring number_canonical_text = clocale_stream.str(); //Avoid << because it does implicit character conversion (though that might not be a problem here. Not sure). murrayc
     //std::cout << "  DEBUG: number_canonical_text=" << number_canonical_text << std::endl;  
@@ -810,6 +823,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   
 #ifdef HAVE_STRPTIME
   //Fall back to strptime():
+  //This fallback will be used in most cases. TODO: Remove the useless? time_get<> code then?
   //It seems to be well known that time_get<> can parse much less than what time_put<> can generate:
   // http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2006/n2070.html
   //
@@ -978,118 +992,5 @@ Gnome::Gda::Value Conversions::convert_value(const Gnome::Gda::Value& value, Fie
   return value;
 }
 
-Glib::RefPtr<Gdk::Pixbuf> Conversions::get_pixbuf_for_gda_value(const Gnome::Gda::Value& value)
-{
-  Glib::RefPtr<Gdk::Pixbuf> result;
-
-  if(value.get_value_type() == GDA_TYPE_BINARY || value.get_value_type() == GDA_TYPE_BLOB)
-  {
-    glong buffer_binary_length;
-    gconstpointer buffer_binary;
-    if(value.get_value_type() == GDA_TYPE_BLOB)
-    {
-      const GdaBlob* blob = value.get_blob();
-      if(gda_blob_op_read_all(blob->op, const_cast<GdaBlob*>(blob)))
-      {
-        buffer_binary_length = blob->data.binary_length;
-        buffer_binary = blob->data.data;
-      }
-      else
-      {
-        buffer_binary_length = 0;
-        buffer_binary = NULL;
-        g_warning("Conversions::get_pixbuf_for_gda_value(): Failed to read BLOB data");
-      }
-    }
-    else
-    {
-      buffer_binary = value.get_binary(buffer_binary_length);
-    }
-
-    /* Note that this is regular binary data, not escaped text representing the binary data: */
-    if(buffer_binary && buffer_binary_length)
-    {
-      //typedef std::list<Gdk::PixbufFormat> type_list_formats;
-      //const type_list_formats formats = Gdk::Pixbuf::get_formats();
-      //std::cout << "Debug: Supported pixbuf formats:" << std::endl;
-      //for(type_list_formats::const_iterator iter = formats.begin(); iter != formats.end(); ++iter)
-      //{
-      //  std::cout << " name=" << iter->get_name() << ", writable=" << iter->is_writable() << std::endl;
-      //}
-
-      Glib::RefPtr<Gdk::PixbufLoader> refPixbufLoader;
-
-      // PixbufLoader::create() is broken in gtkmm before 2.6.something,
-      // so let's do this in C so it works with all 2.6 versions:
-      GError* error = 0;
-      GdkPixbufLoader* loader = gdk_pixbuf_loader_new_with_type(GLOM_IMAGE_FORMAT, &error);
-      if(!error)
-        refPixbufLoader = Glib::wrap(loader);
-      else
-      {
-        std::cerr << "ImageGlom::set_value(): Error while calling gdk_pixbuf_loader_new_with_type(): " << error->message << std::endl;
-        g_error_free(error);
-      }
-
-      /*
-      try
-      {
-        refPixbufLoader = Gdk::PixbufLoader::create(GLOM_IMAGE_FORMAT);
-        g_warning("debug a1");
-      }
-      catch(const Gdk::PixbufError& ex)
-      {
-        refPixbufLoader.clear();
-        g_warning("PixbufLoader::create failed: %s",ex.what().c_str());
-      }
-      */
-
-      if(refPixbufLoader)
-      {
-        guint8* puiData = (guint8*)buffer_binary;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-        try
-        {
-
-          //g_warning("ImageGlom::set_value(): debug: from db: ");
-          //for(int i = 0; i < 10; ++i)
-          //  g_warning("%02X (%c), ", (guint8)puiData[i], (char)puiData[i]);
-
-          refPixbufLoader->write(puiData, (glong)buffer_binary_length);
-          result = refPixbufLoader->get_pixbuf();
-
-          refPixbufLoader->close(); //This throws if write() threw, so it must be inside the try block.
-        }
-#else
-        std::auto_ptr<Glib::Error> error;
-        refPixbufLoader->write(puiData, (glong)buffer_binary_length, error);
-        if(error.get() == NULL)
-        {
-          result = refPixbufLoader->get_pixbuf();
-          refPixbufLoader->close(error);
-        }
-#endif
-
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-        catch(const Glib::Exception& ex)
-        {
-#else
-        if(error.get() != NULL)
-        {
-          const Glib::Exception& ex = *error.get();        
-#endif
-          g_warning("Conversions::get_pixbuf_for_gda_value(): PixbufLoader::write() failed: %s", ex.what().c_str());
-        }
-      }
-
-      //TODO: load the image, using the mime type stored elsewhere.
-      //pixbuf = Gdk::Pixbuf::create_from_data(
-    }
-
-  }
-
-  return result;
-}
-
 } //namespace Glom
 
