@@ -19,6 +19,7 @@
  */
 
 #include "fieldformatting.h"
+#include <glom/libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
 const guint MULTILINE_TEXT_DEFAULT_HEIGHT_LINES = 6;
@@ -31,7 +32,8 @@ FieldFormatting::FieldFormatting()
   m_choices_custom(false),
   m_choices_related(false),
   m_text_format_multiline(false),
-  m_text_multiline_height_lines(MULTILINE_TEXT_DEFAULT_HEIGHT_LINES)
+  m_text_multiline_height_lines(MULTILINE_TEXT_DEFAULT_HEIGHT_LINES),
+  m_horizontal_alignment(HORIZONTAL_ALIGNMENT_AUTO)
 {
 }
 
@@ -47,6 +49,7 @@ FieldFormatting::FieldFormatting(const FieldFormatting& src)
   m_text_font(src.m_text_font),
   m_text_color_foreground(src.m_text_color_foreground),
   m_text_color_background(src.m_text_color_background),
+  m_horizontal_alignment(src.m_horizontal_alignment),
   m_choices_related_field(src.m_choices_related_field),
   m_choices_related_field_second(src.m_choices_related_field_second)
 {
@@ -70,7 +73,8 @@ bool FieldFormatting::operator==(const FieldFormatting& src) const
     (m_text_multiline_height_lines == src.m_text_multiline_height_lines) &&
     (m_text_font == src.m_text_font) &&
     (m_text_color_foreground == src.m_text_color_foreground) &&
-    (m_text_color_background == src.m_text_color_background);
+    (m_text_color_background == src.m_text_color_background) && 
+    (m_horizontal_alignment == src.m_horizontal_alignment);
 }
 
 
@@ -92,6 +96,7 @@ FieldFormatting& FieldFormatting::operator=(const FieldFormatting& src)
   m_text_font = src.m_text_font;
   m_text_color_foreground = src.m_text_color_foreground;
   m_text_color_background = src.m_text_color_background;
+  m_horizontal_alignment = src.m_horizontal_alignment;
 
 //g_warning("FieldFormatting::operator=: m_choices_related_relationship=%s, src.m_choices_related_relationship=%s", m_choices_related_relationship->c_str(), src.m_choices_related_relationship->c_str());
   return *this;
@@ -141,6 +146,18 @@ Glib::ustring FieldFormatting::get_text_format_color_foreground() const
   return m_text_color_foreground;
 }
 
+Glib::ustring FieldFormatting::get_text_format_color_foreground_to_use(const Gnome::Gda::Value& value) const
+{
+  if(m_numeric_format.m_alt_foreground_color_for_negatives)
+  {
+    //TODO: Use some other color if the alternative color is too similar to the foreground color.
+    if(Conversions::get_double_for_gda_value_numeric(value) < 0)
+      return NumericFormat::get_alternative_color_for_negatives();
+  }
+
+  return m_text_color_foreground;
+}
+
 void FieldFormatting::set_text_format_color_background(const Glib::ustring& color)
 {
   m_text_color_background = color;
@@ -151,6 +168,16 @@ Glib::ustring FieldFormatting::get_text_format_color_background() const
   return m_text_color_background;
 }
 
+void FieldFormatting::set_horizontal_alignment(HorizontalAlignment alignment)
+{
+  m_horizontal_alignment = alignment;
+}
+
+FieldFormatting::HorizontalAlignment FieldFormatting::get_horizontal_alignment() const
+{
+  return m_horizontal_alignment;
+}
+
 bool FieldFormatting::get_has_choices() const
 {
   return ( m_choices_related && get_has_relationship_name() && !m_choices_related_field.empty() ) ||
