@@ -21,10 +21,10 @@
 #ifndef GLOM_DATASTRUCTURE_FIELDFORMATTING_H
 #define GLOM_DATASTRUCTURE_FIELDFORMATTING_H
 
-#include "usesrelationship.h"
-#include "../numeric_format.h"
-#include "../relationship.h"
-#include <glom/libglom/sharedptr.h>
+#include <libglom/data_structure/layout/usesrelationship.h>
+#include <libglom/data_structure/numeric_format.h>
+#include <libglom/data_structure/relationship.h>
+#include <libglom/sharedptr.h>
 #include <libgdamm.h>
 
 namespace Glom
@@ -76,17 +76,39 @@ public:
    */
   Glib::ustring get_text_format_font() const;
 
+  /** Set the foreground color to use for text when displaying a field value.
+   */
   void set_text_format_color_foreground(const Glib::ustring& color);
+
+  /** Get the foreground color to use for text for the specified value,
+   * taking the negative-color into account, if specified.
+   */
+  Glib::ustring get_text_format_color_foreground_to_use(const Gnome::Gda::Value& value) const;
+
+  /** Get the foreground color to use for text when displaying a field value.
+   * This should be overriden by by m_numeric_formatting.m_foreground_color_for_negatives
+   * if that is active.
+   */
   Glib::ustring get_text_format_color_foreground() const;
 
   void set_text_format_color_background(const Glib::ustring& color);
   Glib::ustring get_text_format_color_background() const;
 
+  enum HorizontalAlignment
+  {
+    HORIZONTAL_ALIGNMENT_AUTO, //For instance, RIGHT for numeric fields.
+    HORIZONTAL_ALIGNMENT_LEFT,
+    HORIZONTAL_ALIGNMENT_RIGHT,
+  };
+
+  void set_horizontal_alignment(HorizontalAlignment alignment);
+  HorizontalAlignment get_horizontal_alignment() const;
+
   void change_field_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
 
   NumericFormat m_numeric_format; //Only used for numeric fields.
 
-protected:
+private:
 
   type_list_values m_choices_custom_list; //A drop-down list of possible values for the field.
   bool m_choices_restricted;
@@ -97,6 +119,7 @@ protected:
   //Glib::ustring m_text_multiline_width_example; //An example string from which to calculate the width.
   Glib::ustring m_text_font;
   Glib::ustring m_text_color_foreground, m_text_color_background;
+  HorizontalAlignment m_horizontal_alignment;
 
   Glib::ustring m_choices_related_field, m_choices_related_field_second;
 };
