@@ -21,9 +21,10 @@
 #ifndef GLOM_DATASTRUCTURE_LAYOUTITEM_PORTAL_H
 #define GLOM_DATASTRUCTURE_LAYOUTITEM_PORTAL_H
 
-#include "layoutgroup.h"
-#include "../field.h"
-#include "../relationship.h"
+#include <libglom/data_structure/layout/layoutgroup.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/data_structure/relationship.h>
+//#include <libglom/data_structure/has_title_singular.h>
 
 namespace Glom
 {
@@ -31,6 +32,9 @@ namespace Glom
 class LayoutItem_Portal
 : public LayoutGroup,
   public UsesRelationship
+  
+  //TODO: Allow portals to have custom titles that override the relationship titles?
+  //public HasTitleSingular
 {
 public:
 
@@ -51,9 +55,43 @@ public:
 
   //virtual void debug(guint level = 0) const;
 
-  sharedptr<UsesRelationship> get_navigation_relationship_specific(bool& main_relationship);
-  sharedptr<const UsesRelationship> get_navigation_relationship_specific(bool& main_relationship) const;
-  void set_navigation_relationship_specific(bool main_relationship, const sharedptr<UsesRelationship>& relationship);
+  /** Gets the relationship to use for navigation if get_navigation_type() is 
+   * NAVIGATION_NONE.
+   */
+  sharedptr<UsesRelationship> get_navigation_relationship_specific();
+
+  /** Get the @a relationship to use for navigation if get_navigation_type() is 
+   * NAVIGATION_NONE.
+   */
+  sharedptr<const UsesRelationship> get_navigation_relationship_specific() const;
+
+  /** Set the @a relationship to use for navigation if get_navigation_type() is 
+   * NAVIGATION_NONE.
+   */
+  void set_navigation_relationship_specific(const sharedptr<UsesRelationship>& relationship);
+
+  void reset_navigation_relationship();
+
+  /** The navigation (if any) that should be used when the user 
+   * activates a related record row.
+   */
+  enum navigation_type
+  {
+    NAVIGATION_NONE, /**< No navigation will be offered. */
+    NAVIGATION_AUTOMATIC, /**< The destination related table will be chosen automatically based on the relationship and the visible fields. */
+    NAVIGATION_SPECIFIC /**< The destination related table will be determined by a specified relationship. */
+  };
+
+  /** Discover what @a type (if any) navigation should be used when the user 
+   * activates a related record row.
+   */
+  navigation_type get_navigation_type() const;
+
+  /** Set what @a type (if any) navigation should be used when the user 
+   * activates a related record row.
+   */
+  void set_navigation_type(navigation_type type);
+
 
   /// This is used only for the print layouts.
   double get_print_layout_row_height() const;
@@ -61,19 +99,19 @@ public:
   /// This is used only for the print layouts.
   void set_print_layout_row_height(double row_height);
 
+
 private:
 
-  //If no navigation relationship has been specified then it will be automatically chosen: 
-  bool m_navigation_relationship_specific_main;
   sharedptr<UsesRelationship> m_navigation_relationship_specific;
 
   // This is used only for the print layouts.
   double m_print_layout_row_height;
+
+  //If no navigation relationship has been specified then it will be automatically chosen or navigation will be disabled:
+  navigation_type m_navigation_type;
 };
 
 } //namespace Glom
 
 #endif //GLOM_DATASTRUCTURE_LAYOUTITEM_PORTAL_H
 
-
-
