@@ -24,11 +24,11 @@
 #include <eval.h> /* for PyEval_EvalCode */
 #include <objimpl.h> /* for PyObject_New() */
 
-#include <glom/libglom/python_embed/py_glom_record.h>
-#include <glom/libglom/python_embed/py_glom_related.h>
+#include <libglom/python_embed/py_glom_record.h>
+#include <libglom/python_embed/py_glom_related.h>
 #include "pygdavalue_conversions.h" //For pygda_value_as_pyobject().
 
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/data_structure/field.h>
 #include <glibmm/ustring.h>
 
 namespace Glom
@@ -52,103 +52,170 @@ Record_new(PyTypeObject *type, PyObject * /* args */, PyObject * /* kwds */)
 
 //Set the object's member data, from the parameters supplied when creating the object:
 static int
-Record_init(PyGlomRecord *self, PyObject * /* args */, PyObject * /* kwds */)
+Record_init(PyObject *self, PyObject * /* args */, PyObject * /* kwds */)
 {
-  //static char *kwlist[] = {"test", NULL};
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
+  //static char *kwlist[] = {"test", 0};
 
   //if(!PyArg_ParseTupleAndKeywords(args, kwds, "|i", kwlist,
    //                                 &self->m_test))
    // return -1;
 
-  if(self)
+  if(self_record)
   {
-    self->m_related = 0;
+    self_record->m_related = 0;
 
-    if(self->m_pMap_field_values == 0)
-      self->m_pMap_field_values = new PyGlomRecord::type_map_field_values();
+    if(self_record->m_pMap_field_values == 0)
+      self_record->m_pMap_field_values = new PyGlomRecord::type_map_field_values();
   }
 
   return 0;
 }
 
 static void
-Record_dealloc(PyGlomRecord* self)
+Record_dealloc(PyObject* self)
 {
-  if(self->m_pMap_field_values)
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
+  if(self_record->m_pMap_field_values)
   {
-    delete self->m_pMap_field_values;
-    self->m_pMap_field_values = 0;
+    delete self_record->m_pMap_field_values;
+    self_record->m_pMap_field_values = 0;
   }
 
-  self->ob_type->tp_free((PyObject*)self);
+  if(self_record->m_table_name)
+  {
+    delete self_record->m_table_name;
+    self_record->m_table_name = 0;
+  }
+
+  if(self_record->m_connection)
+  {
+    delete self_record->m_connection;
+    self_record->m_connection = 0;
+  }
+
+  self_record->ob_type->tp_free((PyObject*)self_record);
 }
 
+static PyObject *
+Record__get_connection(PyObject* self, void* /* closure */)
+{
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
+  if( !self_record->m_connection || !(*(self_record->m_connection)) )
+  {
+    Py_INCREF(Py_None);
+    return Py_None;
+  }
+  else
+  {
+   return pygobject_new( G_OBJECT( (*(self_record->m_connection))->gobj()) ); //Creates a pygda Connection object.
+  }
+}
 
 static PyObject *
-Record__get_related(PyGlomRecord* self, void* /* closure */)
+Record__get_table_name(PyObject* self, void* /* closure */)
 {
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
+  if( !self_record->m_table_name || (*(self_record->m_table_name)).empty() )
+  {
+    Py_INCREF(Py_None);
+    return Py_None;
+  }
+  else
+  {
+   const Glib::ustring& the_text = *(self_record->m_table_name); //Avoid that ugly dereference.
+   return PyString_FromString(the_text.c_str());
+  }
+}
+
+static PyObject *
+Record__get_related(PyObject* self, void* /* closure */)
+{
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
   //We initialize it here, so that this work never happens if it's not needed:
-  if(!(self->m_related))
+  if(!(self_record->m_related))
   {
     //Return a new RelatedRecord:
     PyObject* new_args = PyTuple_New(0);
-    self->m_related = (PyGlomRelated*)PyObject_Call((PyObject*)PyGlomRelated_GetPyType(), new_args, 0);
+    self_record->m_related = (PyGlomRelated*)PyObject_Call((PyObject*)PyGlomRelated_GetPyType(), new_args, 0);
     Py_DECREF(new_args);
 
     //Fill it:
-    Document_Glom::type_vecRelationships vecRelationships = self->m_document->get_relationships(*(self->m_table_name));
+    Document::type_vec_relationships vecRelationships = self_record->m_document->get_relationships(*(self_record->m_table_name));
     PyGlomRelated::type_map_relationships map_relationships;
-    for(Document_Glom::type_vecRelationships::const_iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
+    for(Document::type_vec_relationships::const_iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
     {
       if(*iter)
         map_relationships[(*iter)->get_name()] = *iter;
     }
 
-    PyGlomRelated_SetRelationships(self->m_related, map_relationships);
+    PyGlomRelated_SetRelationships(self_record->m_related, map_relationships);
 
-    self->m_related->m_record = self;
-    Py_XINCREF(self); //unreffed in the self->m_related's _dealloc. //TODO: Is this a circular reference?
+    self_record->m_related->m_record = self_record;
+    Py_XINCREF(self_record); //unreffed in the self->m_related's _dealloc. //TODO: Is this a circular reference?
   }
 
-  Py_INCREF(self->m_related); //Should we do this?
-  return (PyObject*)self->m_related;
+  Py_INCREF(self_record->m_related); //Should we do this?
+  return (PyObject*)self_record->m_related;
 }
 
 
 static PyGetSetDef Record_getseters[] = {
-    {"related",
+    {(char*)"related",
      (getter)Record__get_related, (setter)0, 0, 0
     },
-    {NULL, 0, 0, 0, 0, }  // Sentinel
+    {(char*)"connection",
+     (getter)Record__get_connection, (setter)0, 0, 0
+    },
+    {(char*)"table_name",
+     (getter)Record__get_table_name, (setter)0, 0, 0
+    },
+    {0, 0, 0, 0, 0, }  // Sentinel
 };
 
-
-
-static int
-Record_tp_as_mapping_length(PyGlomRecord *self)
+//Adapt to API changes in Python 2.5:
+#if defined(PY_VERSION_HEX) && (PY_VERSION_HEX >= 0x02050000) /* Python 2.5 */
+static Py_ssize_t
+Record_tp_as_mapping_length(PyObject *self)
 {
-  return self->m_pMap_field_values->size();
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+  return self_record->m_pMap_field_values->size();
 }
+#else
+static int
+Record_tp_as_mapping_length(PyObject *self)
+{
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+  return (int)(self_record->m_pMap_field_values->size());
+}
+#endif
 
 static PyObject *
-Record_tp_as_mapping_getitem(PyGlomRecord *self, PyObject *item)
+Record_tp_as_mapping_getitem(PyObject *self, PyObject *item)
 {
+  PyGlomRecord *self_record = (PyGlomRecord*)self;
+
   if(PyString_Check(item))
   {
     const char* pchKey = PyString_AsString(item);
     if(pchKey)
     {
       const Glib::ustring key(pchKey);
-      if(self && self->m_pMap_field_values)
+      if(self_record && self_record->m_pMap_field_values)
       {
-        PyGlomRecord::type_map_field_values::const_iterator iterFind = self->m_pMap_field_values->find(key);
-        if(iterFind != self->m_pMap_field_values->end())
+        PyGlomRecord::type_map_field_values::const_iterator iterFind = self_record->m_pMap_field_values->find(key);
+        if(iterFind != self_record->m_pMap_field_values->end())
         {
-          return pygda_value_as_pyobject(iterFind->second.gobj(), true /* copy */);
+          return glom_pygda_value_as_pyobject(iterFind->second.gobj(), true /* copy */);
         }
         else
         {
-          g_warning("Record_tp_as_mapping_getitem(): item not found in m_pMap_field_values. size=%d, item=%s", self->m_pMap_field_values->size(), pchKey);
+          g_warning("Record_tp_as_mapping_getitem(): item not found in m_pMap_field_values. size=%d, item=%s", (int)self_record->m_pMap_field_values->size(), pchKey);
         }
       }
       else
@@ -169,7 +236,7 @@ Record_tp_as_mapping_getitem(PyGlomRecord *self, PyObject *item)
 
   g_warning("Record_tp_as_mapping_getitem(): return null.");
   PyErr_SetString(PyExc_IndexError, "field not found");
-  return NULL;
+  return 0;
 }
 
 /*
@@ -182,16 +249,16 @@ Record_tp_as_mapping_setitem(PyGObject *self, PyObject *item, PyObject *value)
 */
 
 static PyMappingMethods Record_tp_as_mapping = {
-    (inquiry)Record_tp_as_mapping_length,
-    (binaryfunc)Record_tp_as_mapping_getitem,
+    Record_tp_as_mapping_length,
+    Record_tp_as_mapping_getitem,
     (objobjargproc)0 /* Record_tp_as_mapping_setitem */
 };
 
 
 static PyTypeObject pyglom_RecordType = {
-    PyObject_HEAD_INIT(NULL)
+    PyObject_HEAD_INIT(0)
     0,                         /*ob_size*/
-    "glom.Record",             /*tp_name*/
+    (char*)"glom.Record",             /*tp_name*/
     sizeof(PyGlomRecord), /*tp_basicsize*/
     0,                         /*tp_itemsize*/
     (destructor)Record_dealloc, /*tp_dealloc*/
@@ -210,7 +277,7 @@ static PyTypeObject pyglom_RecordType = {
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
     Py_TPFLAGS_DEFAULT,        /*tp_flags*/
-    "Glom objects",           /* tp_doc */
+    (char*)"Glom objects",           /* tp_doc */
     0,                  /* tp_traverse */
     0,                   /* tp_clear */
     0,                   /* tp_richcompare */
@@ -228,7 +295,7 @@ static PyTypeObject pyglom_RecordType = {
     (initproc)Record_init,      /* tp_init */
     0,                         /* tp_alloc */
     Record_new,                 /* tp_new */
-    0, 0, 0, 0, 0, 0, 0, 0,
+    0, 0, 0, 0, 0, 0, 0, 0, //TODO: or one more 0 if using a newer Python.
 };
 
 PyTypeObject* PyGlomRecord_GetPyType()
@@ -247,11 +314,18 @@ static void Record_HandlePythonError()
 */
 
 
-void PyGlomRecord_SetFields(PyGlomRecord* self, const PyGlomRecord::type_map_field_values& field_values, Document_Glom* document, const Glib::ustring& table_name)
+void PyGlomRecord_SetFields(PyGlomRecord* self, const PyGlomRecord::type_map_field_values& field_values, Document* document, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
-  *(self->m_pMap_field_values) = field_values;
-  self->m_table_name = new Glib::ustring(table_name);
-  self->m_document = document;
+  *(self->m_pMap_field_values) = field_values; //This was allocated in Record_new().
+
+  if(self->m_table_name == 0)
+    self->m_table_name = new Glib::ustring(table_name); //Deleted in Record_dealloc().
+
+  if(self->m_document == 0)
+    self->m_document = document;
+
+  if(self->m_connection == 0)
+    self->m_connection = new Glib::RefPtr<Gnome::Gda::Connection>(opened_connection);  //Deleted in Record_dealloc().
 
   /*
   if(self->m_fields_dict == 0)
