@@ -24,7 +24,7 @@
 #include "config.h" // GLOM_ENABLE_CLIENT_ONLY
 
 #include "box_data_manyrecords.h"
-#include "../utility_widgets/db_adddel/db_adddel_withbuttons.h"
+#include <glom/utility_widgets/db_adddel/db_adddel_withbuttons.h>
 
 namespace Glom
 {
@@ -61,6 +61,7 @@ public:
 
 
   //Signal Handlers:
+  //TODO: Remove virtual?
   virtual void on_details_nav_first();
   virtual void on_details_nav_previous();
   virtual void on_details_nav_next();
@@ -81,7 +82,7 @@ protected:
 
   //Overrides of functions from Box_Data:
   virtual void create_layout(); //override
-  virtual Document_Glom::type_list_layout_groups create_layout_get_layout();
+  virtual Document::type_list_layout_groups create_layout_get_layout();
   void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
     
   virtual bool fill_from_database(); //override.
