@@ -40,6 +40,10 @@ public:
    */
   virtual bool init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title = true);
 
+  /** Use this if no portal is yet defined, so the user can use the context menu to define a portal.
+   */
+  virtual bool init_db_details(const Glib::ustring& parent_table, bool show_title = true);
+
 protected:
   virtual bool fill_from_database(); //Override.
 
@@ -70,7 +74,7 @@ protected:
  
   //Overrides of functions from Box_Data:
   virtual void create_layout(); //override
-  virtual Document_Glom::type_list_layout_groups create_layout_get_layout();
+  virtual Document::type_list_layout_groups create_layout_get_layout();
   void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
     
   virtual void enable_buttons(); //override
