@@ -19,12 +19,12 @@
  */
 
 #include "box_data_manyrecords.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <glom/libglom/glade_utils.h>
-#include <glom/reports/report_builder.h>
-#include "dialog_layout_list.h"
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/glade_utils.h>
+#include <glom/report_builder.h>
+#include <glom/mode_design/layout/dialog_layout_list.h>
 #include <glom/glom_privs.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 #include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
@@ -54,7 +54,7 @@ void Box_Data_ManyRecords::refresh_data_from_database_blank()
 }
 
 /*
-Document_Glom::type_list_layout_groups Box_Data_ManyRecords::create_layout_get_layout()
+Document::type_list_layout_groups Box_Data_ManyRecords::create_layout_get_layout()
 {
   //Overriden in Box_Data_ManyRecords_Related:
   return get_data_layout_groups(m_layout_name); 
