@@ -36,6 +36,7 @@
 #include <glom/utils_ui.h> //For bold_message()).
 #include <libglom/data_structure/layout/layoutitem_placeholder.h>
 #include <glom/signal_reemitter.h>
+
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -193,7 +194,12 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     Gtk::Alignment* alignment = Gtk::manage( new Gtk::Alignment ); //TODO_leak: This is possibly leaked, according to valgrind.
 
     if(!group->get_title().empty()) //Don't indent if it has no title, to allow use of groups just for positioning.
+    {
       alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, 6, 0); //Use left-padding of 6 even on Maemo because indentation is important.
+      #ifdef GLOM_ENABLE_MAEMO
+      std::cerr << "DEBUG: Unexpected group with title causing extra spacing on Maemo." << std::endl;
+      #endif
+    }
 
     alignment->show();
     frame->add(*alignment);
@@ -202,8 +208,11 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     add_view(flow_table); //Allow these sub-flowtables to access the document too.
     flow_table->set_table(m_table_name);
 
-    flow_table->set_columns_count(group->m_columns_count);
-    flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+    flow_table->set_columns_count(group->get_columns_count());
+    
+    //Use the parent table's padding:
+    flow_table->set_column_padding(get_column_padding());
+    flow_table->set_row_padding(get_row_padding());
     flow_table->show();
     
     Gtk::EventBox* event_box = Gtk::manage( new Gtk::EventBox() ); //TODO_Leak: Valgrind says this is possibly leaked.
@@ -387,8 +396,9 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
         add_view(flow_table); //Allow these sub-flowtables to access the document too.
         flow_table->set_table(m_table_name);
 
-        flow_table->set_columns_count(group->m_columns_count);
-        flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+        flow_table->set_columns_count(group->get_columns_count());
+        flow_table->set_column_padding(get_column_padding());
+        flow_table->set_row_padding(get_row_padding());
         flow_table->show();
         
         // Put the new flowtable in an event box to catch events
@@ -476,7 +486,8 @@ void FlowTableWithFields::add_group(const Glib::ustring& group_name, const Glib:
     FlowTableWithFields* flow_table = Gtk::manage( new FlowTableWithFields() );
 
     flow_table->set_columns_count(1);
-    flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+    flow_table->set_column_padding(get_column_padding());
+    flow_table->set_row_padding(get_row_padding());
     flow_table->show();
     alignment->add(*flow_table);
 
@@ -583,28 +594,54 @@ void FlowTableWithFields::add_button_at_position(const sharedptr<LayoutItem_Butt
     
   add_layoutwidgetbase(button, add_before);
   //add_view(button); //So it can get the document.
+  
+  const FieldFormatting::HorizontalAlignment alignment =
+    layoutitem_button->get_formatting_used_horizontal_alignment();
+  Gtk::Widget* widget_to_add = button;
+  bool expand = false;
+  if(alignment != FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT)
+  {
+    //Put the button in a Gtk::HBox so we can have non-default alignment in 
+    //its space. Note that we will need a different technique if we ever 
+    //support center alignment.
+    Gtk::HBox* box_button = Gtk::manage(new Gtk::HBox());
+    box_button->show();
+    if(alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_RIGHT)
+      box_button->pack_end(*button, Gtk::PACK_SHRINK);
+    else
+      box_button->pack_start(*button, Gtk::PACK_SHRINK);
+      
+    widget_to_add = box_button;
+    expand = true;
+  }
 
   Gtk::Widget* widget = dynamic_cast<Gtk::Widget*>(*add_before);
   if(widget)
-    insert_before (*button, *widget, false /* expand */);
+    insert_before (*widget_to_add, *widget, expand);
   else
-    add(*button, false /* expand */);
+    add(*widget_to_add, expand);
+
+  apply_formatting(*button, layoutitem_button);
 }
 
 void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_Text>& layoutitem_text, const Glib::ustring& table_name , const type_list_layoutwidgets::iterator& add_before)
 {
   //Add the widget:
+  
+  const FieldFormatting::HorizontalAlignment alignment =
+    layoutitem_text->get_formatting_used_horizontal_alignment();
+  const Gtk::AlignmentEnum x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_LEFT : Gtk::ALIGN_RIGHT);
   Gtk::Alignment* alignment_label = Gtk::manage(new Gtk::Alignment());
-  alignment_label->set(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
+  alignment_label->set(x_align, Gtk::ALIGN_CENTER);
   alignment_label->show();
   
   const Glib::ustring text = layoutitem_text->get_text();
-  LabelGlom* label = Gtk::manage(new LabelGlom(text, 0.0 /* xalign */, 0.5 /* yalign */)); //The alignment here seems to be necessary as well (or instead of) the parent Gtk::Alignment.
+  LabelGlom* label = Gtk::manage(new LabelGlom(text));
   label->set_layout_item(layoutitem_text, table_name);
   label->show();
   alignment_label->add(*label);
   
-  apply_formatting(*label, layoutitem_text->get_formatting_used());
+  apply_formatting(*label, layoutitem_text);
 
   add_layoutwidgetbase(label, add_before);
 
@@ -613,9 +650,9 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
   {
     Gtk::Widget* widget = dynamic_cast<Gtk::Widget*>(*add_before);
     if(widget)
-      insert_before(*alignment_label, *widget, false /* expand */);
+      insert_before(*alignment_label, *widget, true /* expand */);
     else
-      add(*alignment_label, false /* expand */);
+      add(*alignment_label, true /* expand */);
   }
   else
   {
@@ -631,9 +668,9 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
     
     Gtk::Widget* widget = dynamic_cast<Gtk::Widget*>(*add_before);
     if(widget)
-      insert_before (*alignment_title, *alignment_label, *widget, false /* expand */);
+      insert_before (*alignment_title, *alignment_label, *widget, true /* expand */);
     else
-      add(*alignment_title, *alignment_label, false /* expand */);
+      add(*alignment_title, *alignment_label, true /* expand */);
   }
 }
 
@@ -651,7 +688,7 @@ void FlowTableWithFields::add_placeholder_at_position(const sharedptr<LayoutItem
   m_placeholder->set(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
   m_placeholder->show();
 
-  PlaceholderGlom* preview = Gtk::manage (new PlaceholderGlom);
+  PlaceholderGlom* preview = Gtk::manage(new PlaceholderGlom);
   preview->show();
 
   m_placeholder->add(*preview);
@@ -1206,6 +1243,42 @@ void FlowTableWithFields::on_flowtable_requested_related_details(const Glib::ust
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+
+void FlowTableWithFields::on_dnd_add_layout_item_by_type(int item_type_num, Gtk::Widget* above_widget)
+{
+  LayoutWidgetBase::enumType item_type = static_cast<LayoutWidgetBase::enumType>(item_type_num);
+  LayoutWidgetBase* above = dynamic_cast<LayoutWidgetBase*>(above_widget);
+  if(!above)
+    return;
+
+  switch(item_type)
+  {
+    case LayoutWidgetBase::TYPE_FIELD:
+      on_dnd_add_layout_item_field(above);
+      break;
+    case LayoutWidgetBase::TYPE_BUTTON:
+      on_dnd_add_layout_item_button(above);
+      break;
+    case LayoutWidgetBase::TYPE_TEXT:
+      on_dnd_add_layout_item_text(above);
+      break;
+    case LayoutWidgetBase::TYPE_IMAGE:
+      on_dnd_add_layout_item_image(above);
+      break;
+    case LayoutWidgetBase::TYPE_GROUP:
+      on_dnd_add_layout_group(above);
+      break;
+    case LayoutWidgetBase::TYPE_NOTEBOOK:
+      on_dnd_add_layout_notebook(above);
+      break;
+    case LayoutWidgetBase::TYPE_PORTAL:
+      on_dnd_add_layout_portal(above);
+      break;
+    default:
+      std::cerr << "FlowTableWithFields::on_dnd_add_layout_item(): Unknown drop type: " << item_type << std::endl;
+   }
+}
+
 void FlowTableWithFields::on_dnd_add_layout_item_field(LayoutWidgetBase* above)
 {
   //Ask the user to choose the layout item
@@ -1275,9 +1348,8 @@ void FlowTableWithFields::on_dnd_add_layout_item_button(LayoutWidgetBase* above)
   sharedptr<LayoutItem_Button> layout_item_button = sharedptr<LayoutItem_Button>::create();
   layout_item_button->set_title(_("New Button")); //Give the button a default title, so it is big enough, and so people see that they should change it.
   layout_item_button->set_name("new_button");
-  sharedptr<LayoutItem> layout_item = sharedptr<LayoutItem>::cast_dynamic(layout_item_button);
 
-  dnd_add_to_layout_group(layout_item, above);
+  dnd_add_to_layout_group(layout_item_button, above);
   //Tell the parent to tell the document to save the layout:
   signal_layout_changed().emit();
 }
@@ -1290,7 +1362,7 @@ void FlowTableWithFields::on_dnd_add_layout_item_text(LayoutWidgetBase* above)
   textobject->set_text(_("New Text"));
   sharedptr<LayoutItem> layout_item = sharedptr<LayoutItem>::cast_dynamic(textobject);
 
-  dnd_add_to_layout_group (layout_item, above);
+  dnd_add_to_layout_group(layout_item, above);
   //Tell the parent to tell the document to save the layout
 
   signal_layout_changed().emit();
@@ -1302,7 +1374,7 @@ void FlowTableWithFields::on_dnd_add_layout_item_image(LayoutWidgetBase* above)
   sharedptr<LayoutItem_Image> image_object = sharedptr<LayoutItem_Image>::create();
   sharedptr<LayoutItem> layout_item = sharedptr<LayoutItem>::cast_dynamic(image_object);
 
-  dnd_add_to_layout_group (layout_item, above);
+  dnd_add_to_layout_group(layout_item, above);
   //Tell the parent to tell the document to save the layout
 
   signal_layout_changed().emit();
@@ -1316,8 +1388,12 @@ void FlowTableWithFields::on_dnd_add_layout_item(LayoutWidgetBase* above, const
   // signal_layout_changed().emit();
 }
 
-void FlowTableWithFields::on_dnd_add_placeholder(LayoutWidgetBase* above)
+void FlowTableWithFields::on_dnd_add_placeholder(Gtk::Widget* above_widget)
 {
+  LayoutWidgetBase* above = dynamic_cast<LayoutWidgetBase*>(above_widget);
+  if(!above)
+    return;
+
   if(m_placeholder)
   {
     if(dynamic_cast<Glom::PlaceholderGlom*>(above))
@@ -1331,6 +1407,7 @@ void FlowTableWithFields::on_dnd_add_placeholder(LayoutWidgetBase* above)
   sharedptr<LayoutItem_Placeholder> placeholder_field(new LayoutItem_Placeholder);
   sharedptr<LayoutItem> item = sharedptr<LayoutItem>::cast_dynamic(placeholder_field);  
   add_layout_item_at_position(placeholder_field, cur_widget);
+
   dnd_add_to_layout_group(item, above, true /* ignore error*/);
 }
 
@@ -1344,7 +1421,7 @@ void FlowTableWithFields::on_dnd_remove_placeholder()
     { 
       LayoutGroup::type_list_items items = layout_group->get_items();
       for (LayoutGroup::type_list_items::iterator item = items.begin();
-           item != items.end(); item++)
+           item != items.end(); ++item)
       {
         sharedptr<LayoutItem_Placeholder> placeholder = 
           sharedptr<LayoutItem_Placeholder>::cast_dynamic(*item);
@@ -1364,7 +1441,8 @@ void FlowTableWithFields::on_dnd_remove_placeholder()
 
 void FlowTableWithFields::dnd_notify_failed_drop()
 {
-  // TODO: Avoid this error message
+  // TODO: Avoid this error message, maybe by adding a group.
+  // TODO: At least avoid losing the dragged item.
   Gtk::MessageDialog dialog(_("You cannot drop anything here. Try to add a group first"),
                       false, Gtk::MESSAGE_ERROR);
   dialog.run();
@@ -1406,7 +1484,7 @@ void FlowTableWithFields::on_menu_properties_activate()
       if(response == Gtk::RESPONSE_OK)
       {
         sharedptr<LayoutGroup> group = get_layout_group();
-        group->m_columns_count = dialog->get_columns_count();
+        group->set_columns_count( dialog->get_columns_count() );
         group->set_title(dialog->get_title());
         signal_layout_changed().emit();
       }
@@ -1501,6 +1579,26 @@ sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
   }
   return sharedptr<LayoutItem_Portal>();
 }
+
+void FlowTableWithFields::set_child_widget_dnd_in_progress(Gtk::Widget* child, bool in_progress)
+{
+  //To be reimplemented by derived classes.
+  LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(child);
+  if(!child)
+    return;
+
+  base->set_dnd_in_progress(in_progress); 
+}
+
+bool FlowTableWithFields::get_child_widget_dnd_in_progress(Gtk::Widget* child) const
+{
+  LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(child);
+  if(!base)
+    return false;
+  else
+    return base->get_dnd_in_progress();
+}
+
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 } //namespace Glom
