@@ -21,11 +21,11 @@
 #ifndef WINDOW_PRINT_LAYOUT_EDIT_H
 #define WINDOW_PRINT_LAYOUT_EDIT_H
 
-#include <glom/libglom/data_structure/print_layout.h>
-#include <glom/mode_design/print_layouts/canvas_print_layout.h>
+#include <libglom/data_structure/print_layout.h>
+#include <glom/print_layout/canvas_print_layout.h>
 #include <glom/mode_design/print_layouts/print_layout_toolbar.h>
 #include <glom/mode_design/print_layouts/print_layout_toolbar_button.h>
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 #include <gtkmm/window.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
@@ -33,7 +33,7 @@
 #include <gtkmm/uimanager.h>
 //#include <gtkmm/toggleaction.h>
 #include <gtkmm/ruler.h>
-#include <libglademm/xml.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -43,7 +43,7 @@ class Window_PrintLayout_Edit
   public View_Composite_Glom
 {
 public:
-  Window_PrintLayout_Edit(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Window_PrintLayout_Edit(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Window_PrintLayout_Edit();
 
   virtual bool init_db_details(const Glib::ustring& table_name);
@@ -52,7 +52,7 @@ public:
   Glib::ustring get_original_name() const;
   sharedptr<PrintLayout> get_print_layout();
 
-protected:
+private:
 
   void enable_buttons();
   void init_menu();
