@@ -21,25 +21,30 @@
 #ifndef GLOM_MODE_DESIGN_USERS_DIALOG_NEWGROUP_H
 #define GLOM_MODE_DESIGN_USERS_DIALOG_NEWGROUP_H
 
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 #include "../../utility_widgets/combo_textglade.h"
 
+namespace Glom
+{
+
 class Dialog_ChooseUser : public Gtk::Dialog
 {
 public:
-  Dialog_ChooseUser(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_ChooseUser(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_ChooseUser();
 
-  typedef std::vector<Glib::ustring> type_vecStrings;
-  void set_user_list(const type_vecStrings& users);
+  typedef std::vector<Glib::ustring> type_vec_strings;
+  void set_user_list(const type_vec_strings& users);
 
   Glib::ustring get_user() const;
 
-protected:
+private:
   Combo_TextGlade* m_combo_name;
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DESIGN_USERS_DIALOG_NEWGROUP_H
 
