@@ -99,7 +99,7 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
     #endif
     
     //TODO: Use this when gtkmm and GTK+ have been fixed: page_setup = Gtk::PageSetup::create(key_file);
-    page_setup = Glib::wrap(gtk_page_setup_new_from_key_file(key_file.gobj(), NULL, NULL));
+    page_setup = Glib::wrap(gtk_page_setup_new_from_key_file(key_file.gobj(), 0, 0));
   }
 
   set_page_setup(page_setup);
@@ -290,7 +290,7 @@ void Canvas_PrintLayout::setup_context_menu()
   #else
   std::auto_ptr<Glib::Error> error;
   m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
@@ -842,7 +842,7 @@ void Canvas_PrintLayout::set_canvas_item_field_value(const Glib::RefPtr<Goocanva
     }
 
     //FieldFormatting& formatting = field->m_formatting;
-    //check_and_apply_formatting(canvas_item, formatting);
+    //apply_formatting(canvas_item, formatting);
     const Glib::ustring text = 
       Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->m_formatting.m_numeric_format);
     canvas_text->set_text(text);
