@@ -30,11 +30,11 @@
 #include <libglom/python_embed/py_glom_relatedrecord.h>
 
 static PyMethodDef pyglom_methods[] = {
-    {NULL, 0, 0, 0}  /* Sentinel */
+    {0, 0, 0, 0}  /* Sentinel */
 };
 
 PyMODINIT_FUNC
-initglom_1_12(void) 
+initglom_1_14(void) 
 {
   PyObject* m;
 
