@@ -18,25 +18,24 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
+#include "config.h" // For GLOM_ENABLE_MAEMO
 
-#include "adddel.h"
+#include <glom/utility_widgets/adddel/adddel.h>
 #include <algorithm> //For std::find.
 #include <glibmm/i18n.h>
-#include "../cellrendererlist/cellrendererlist.h"
-#include "treeviewcolumn_glom.h"
+#include <glom/utility_widgets/cellrendererlist/cellrendererlist.h>
+#include <glom/utility_widgets/adddel/treeviewcolumn_glom.h>
 #include <libglom/data_structure/glomconversions.h>
-#include "../../dialog_invalid_data.h"
+#include <glom/dialog_invalid_data.h>
+#include <glom/utils_ui.h>
 #include <libglom/utils.h>
-#include "bakery/App/App_Gtk.h"
+//#include <glom/bakery/app_gtk.h>
 #include <iostream> //For debug output.
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/note.h>
 #endif // GLOM_ENABLE_MAEMO
 
-#include "eggcolumnchooser/eggcolumnchooserdialog.h"
-
 namespace Glom
 {
 
@@ -86,7 +85,7 @@ AddDel::AddDel()
 }
 
 
-AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
+AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::VBox(cobject),
   m_col_key(0),
   m_pMenuPopup(0),
@@ -145,6 +144,13 @@ AddDel::~AddDel()
 {
 }
 
+void AddDel::set_treeview_accessible_name(const Glib::ustring& name)
+{
+#ifdef GTKMM_ATKMM_ENABLED
+  m_TreeView.get_accessible()->set_name(name);
+#endif  
+}
+
 void AddDel::warn_about_duplicate()
 {
   Glib::ustring message;
@@ -157,7 +163,7 @@ void AddDel::warn_about_duplicate()
 #ifdef GLOM_ENABLE_MAEMO
   Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, message);
 #else
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
+  Gtk::MessageDialog dialog(Utils::bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
 #endif
   //TODO: dialog.set_transient_for(get_parent_window());
@@ -210,14 +216,6 @@ AddDel::on_MenuPopup_activate_Edit()
   }
 }
 
-void AddDel::on_MenuPopup_activate_ChooseColumns()
-{
-  GtkDialog* pDialog = GTK_DIALOG( egg_column_chooser_dialog_new(m_TreeView.gobj()) );
-  gtk_widget_show_all( GTK_WIDGET(pDialog) );
-  gtk_dialog_run(pDialog); //It will delete itself. The C API is funny like that.
-  pDialog = 0;
-}
-
 void AddDel::on_MenuPopup_activate_Delete()
 {
   finish_editing();
@@ -278,7 +276,7 @@ void AddDel::setup_menu()
 #else
   std::auto_ptr<Glib::Error> error;
   m_refUIManager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
@@ -652,8 +650,8 @@ void AddDel::construct_specified_columns()
           CellRendererList* pCellRenderer = Gtk::manage( new CellRendererList() );
 
           //Add the choices:
-          const type_vecStrings vecStrings = m_ColumnTypes[model_column_index].m_choices;
-          for(type_vecStrings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+          const type_vec_strings vecStrings = m_ColumnTypes[model_column_index].m_choices;
+          for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
           {
             pCellRenderer->append_list_item(*iter);
           }
@@ -701,7 +699,7 @@ void AddDel::construct_specified_columns()
           if(pCellRenderer)
           {
             //Make it editable:
-            g_object_set(pCellRenderer->gobj(), "editable", TRUE, (gpointer)NULL);
+            g_object_set(pCellRenderer->gobj(), "editable", TRUE, (gpointer)0);
 
             //Connect to its signal:
             pCellRenderer->signal_edited().connect(
@@ -713,7 +711,7 @@ void AddDel::construct_specified_columns()
            Gtk::CellRendererToggle* pCellRenderer = dynamic_cast<Gtk::CellRendererToggle*>(m_TreeView.get_column_cell_renderer(view_column_index));
            if(pCellRenderer)
            {
-             g_object_set(pCellRenderer->gobj(), "activatable", TRUE, (gpointer)NULL);
+             g_object_set(pCellRenderer->gobj(), "activatable", TRUE, (gpointer)0);
 
              //Connect to its signal:
              pCellRenderer->signal_toggled().connect(
@@ -953,7 +951,7 @@ void AddDel::set_prevent_user_signals(bool bVal)
   m_bPreventUserSignals = bVal;
 }
 
-void AddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
+void AddDel::set_column_choices(guint col, const type_vec_strings& vecStrings)
 {
   InnerIgnore innerIgnore(this); //Stop on_treeview_columns_changed() from doing anything when it is called just because we add new columns.
 
@@ -968,7 +966,7 @@ void AddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
     {
       //Add the choices:
       pCellRenderer->remove_all_list_items();
-      for(type_vecStrings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+      for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
       {
         pCellRenderer->append_list_item(*iter);
       }
@@ -1002,11 +1000,6 @@ bool AddDel::get_allow_user_actions() const
   return m_bAllowUserActions;
 }
 
-void AddDel::set_show_column_titles(bool bVal)
-{
-  m_TreeView.set_headers_visible(bVal);
-}
-
 
 void AddDel::set_column_width(guint /* col */, guint /*width*/)
 {
@@ -1410,7 +1403,7 @@ void AddDel::on_treeview_columns_changed()
   }
 }
 
-AddDel::type_vecStrings AddDel::get_columns_order() const
+AddDel::type_vec_strings AddDel::get_columns_order() const
 {
   //This list is rebuilt in on_treeview_columns_changed, but maybe we could just build it here.
   return m_vecColumnIDs;
@@ -1595,11 +1588,6 @@ guint AddDel::get_count_hidden_system_columns()
   return hidden_count;
 }
 
-void AddDel::set_rules_hint(bool val)
-{
-  m_TreeView.set_rules_hint(val);
-}
-
 void AddDel::prevent_duplicates(guint column_number)
 {
   if(column_number < m_ColumnTypes.size())
@@ -1639,7 +1627,7 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
       //std::cout << "value_text=" << value_text << std::endl;
 
       //Look at each other row to see whether the value exists there already:
-      for(Gtk::TreeModel::iterator iterCheck = m_refListStore->children().begin(); iterCheck != m_refListStore->children().end(); iterCheck++)
+      for(Gtk::TreeModel::iterator iterCheck = m_refListStore->children().begin(); iterCheck != m_refListStore->children().end(); ++iterCheck)
       {
         if(iterCheck != iter) //Don't compare the row with itself
         {
