@@ -115,12 +115,14 @@ DbAddDel::DbAddDel()
   pack_start(m_ScrolledWindow);
   #else
   //Do not let the treeview emit activated as soon as a row is pressed.
-  //TODO: Allow this default mamoe behaviour?
+  //TODO: Allow this default maemo behaviour?
   g_object_set(m_TreeView.gobj(), "hildon-ui-mode", HILDON_UI_MODE_NORMAL, (void*)0);
   
   //Allow get_selected() and get_active() to work:
   m_TreeView.set_column_selection_mode(Hildon::TOUCH_SELECTOR_SELECTION_MODE_SINGLE);
   pack_start(m_TreeView);
+  
+  m_TreeView.signal_changed().connect(sigc::mem_fun(*this, &DbAddDel::on_maemo_touchselector_changed));
   #endif //GLOM_ENABLE_MAEMO
 
   m_TreeView.show();
@@ -232,6 +234,14 @@ void DbAddDel::on_MenuPopup_activate_layout()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+#ifdef GLOM_ENABLE_MAEMO
+void DbAddDel::on_maemo_touchselector_changed(int /* column */)
+{
+  if(!m_bIgnoreTreeViewSignals)
+    do_user_requested_edit();
+}
+#endif //GLOM_ENABLE_MAEMO
+
 #ifdef GLOM_ENABLE_MAEMO
 void DbAddDel::setup_menu()
 {
@@ -308,7 +318,7 @@ void DbAddDel::setup_menu()
 #else
   std::auto_ptr<Glib::Error> error;
   m_refUIManager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
@@ -640,23 +650,55 @@ void DbAddDel::set_column_title(guint col, const Glib::ustring& strText)
 
 int DbAddDel::get_fixed_cell_height()
 {
-  if(m_fixed_cell_height > 0)
-    return m_fixed_cell_height;
-  else
+  if(m_fixed_cell_height <= 0)
   {
-    //Discover a suitable height:
+    // Discover a suitable height, and cache it,
+    // by looking at the heights of all columns:
+    // Note that this is usually calculated during construct_specified_columns(), 
+    // when all columns are known.
+    
+    //Get a default:
     Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout("example");
     int width = 0;
     int height = 0;
     refLayout->get_pixel_size(width, height);
-
     m_fixed_cell_height = height;
-    return m_fixed_cell_height;
+
+    //Look at each column:
+    for(type_ColumnTypes::iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
+    {
+      Glib::ustring font_name;
+
+      sharedptr<LayoutItem_WithFormatting> item_withformatting = sharedptr<LayoutItem_WithFormatting>::cast_dynamic(iter->m_item);
+      if(item_withformatting)
+      {
+         const FieldFormatting& formatting = item_withformatting->get_formatting_used();
+         font_name = formatting.get_text_format_font();
+      }
+
+      if(font_name.empty())
+        continue;
+
+      // Translators: This is just some example text used to discover an appropriate height for user-entered text in the UI. This text itself is never shown to the user.
+      Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout(_("Example"));
+      const Pango::FontDescription font(font_name);
+      refLayout->set_font_description(font);
+      int width = 0;
+      int height = 0;
+      refLayout->get_pixel_size(width, height);
+
+      if(height > m_fixed_cell_height)
+        m_fixed_cell_height = height;
+    }
   }
+
+  return m_fixed_cell_height;
 }
 
 Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const sharedptr<LayoutItem>& layout_item, int model_column_index, int data_model_column_index)
 {
+  InnerIgnore innerIgnore(this); //see comments for InnerIgnore class
+
   Gtk::CellRenderer* pCellRenderer = 0;
 
   //Create the appropriate cellrenderer type:
@@ -695,11 +737,6 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
         break;
       }
     } //switch
-
-    //Set font and colors:
-    const FieldFormatting& formatting = item_field->get_formatting_used();
-    if(pCellRenderer)
-      apply_formatting(pCellRenderer, formatting);
   }
   else
   {
@@ -748,6 +785,12 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
      }
   }
 
+  //Use formatting:
+  sharedptr<LayoutItem_WithFormatting> item_withformatting = sharedptr<LayoutItem_WithFormatting>::cast_dynamic(layout_item);
+  if(item_withformatting && pCellRenderer)
+  {
+    apply_formatting(pCellRenderer, item_withformatting);
+  }
   
   //Set extra cellrenderer attributes, depending on the type used:
   Gtk::CellRendererText* pCellRendererText = dynamic_cast<Gtk::CellRendererText*>(pCellRenderer);
@@ -756,10 +799,11 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
     //Use an ellipze to indicate excessive text, 
     //so that similar values do not look equal, 
     //and to avoid multi-line comments. TODO: Is there a better way to restrict the height? This doesn't actually truncate multilines anyway.
-    g_object_set(pCellRendererText->gobj(), "ellipsize", PANGO_ELLIPSIZE_END, (gpointer)NULL);
+    g_object_set(pCellRendererText->gobj(), "ellipsize", PANGO_ELLIPSIZE_END, (gpointer)0);
 
     //Restrict the height, to prevent multiline text cells,
     //and to allow TreeView performance optimisation:
+    //TODO: Avoid specifying a width for the last column?
     int suitable_width = 0;
     pCellRendererText->get_property("width", suitable_width);
     pCellRendererText->set_fixed_size(suitable_width, get_fixed_cell_height() );
@@ -771,10 +815,6 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
       //Make it editable:
       pCellRendererText->set_property("editable", true);
 
-      //Align numbers to the right: //TODO: Avoid this for ID keys.
-      if(item_field->get_glom_type() == Field::TYPE_NUMERIC )
-        pCellRendererText->set_property("xalign", 1.0);
-
       //Connect to its signal:
       pCellRendererText->signal_edited().connect(
         sigc::bind( sigc::mem_fun(*this, &DbAddDel::on_treeview_cell_edited), model_column_index, data_model_column_index) );
@@ -869,13 +909,26 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
   return pCellRenderer;
 }
 
-void DbAddDel::apply_formatting(Gtk::CellRenderer* renderer, const FieldFormatting& formatting)
+void DbAddDel::apply_formatting(Gtk::CellRenderer* renderer, const sharedptr<const LayoutItem_WithFormatting>& layout_item)
 {
   Gtk::CellRendererText* text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
   if(!text_renderer)
     return;
 
   //Use the text formatting:
+
+  //Horizontal alignment:
+  const FieldFormatting::HorizontalAlignment alignment =
+    layout_item->get_formatting_used_horizontal_alignment();
+  const float x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
+#ifdef GLIBMM_PROPERTIES_ENABLED  
+      text_renderer->property_xalign() = x_align;
+#else    
+      text_renderer->set_property("xalign", alignment);
+#endif
+
+  const FieldFormatting& formatting = layout_item->get_formatting_used();
+
   const Glib::ustring font_desc = formatting.get_text_format_font();
   if(!font_desc.empty())
 #ifdef GLIBMM_PROPERTIES_ENABLED  
@@ -989,6 +1042,7 @@ void DbAddDel::construct_specified_columns()
     {
       //Create the model from the ColumnRecord:
       //Note that the model will use a dummy Gda DataModel if m_find_mode is true.
+      //std::cout << "debug: Creating new type_model_store() for table=" << m_found_set.m_table_name << std::endl;
       m_refListStore = type_model_store::create(record, m_found_set, fields, column_index_key, m_allow_view, m_find_mode);
     }
     else
@@ -1005,9 +1059,10 @@ void DbAddDel::construct_specified_columns()
  
   #ifdef GLOM_ENABLE_MAEMO
   //Remove all View columns:
-  Glib::RefPtr<Hildon::TouchSelectorColumn> column = touch_selector_get_column();
-  g_assert(column);
-  column->clear();
+  while(m_TreeView.get_num_columns())
+  {
+    m_TreeView.remove_column(0);
+  }
   #else
   m_TreeView.set_model(m_refListStore); // clear old model from treeview
 
@@ -1042,7 +1097,9 @@ void DbAddDel::construct_specified_columns()
     // the spacing property of the treeviewcolumn.
     int horizontal_separator = 0;
     m_TreeView.get_style_property("horizontal-separator", horizontal_separator);
-    m_treeviewcolumn_button->set_fixed_width(width + horizontal_separator*2);
+    const int button_width = width + horizontal_separator*2;
+    if(button_width > 0) //Otherwise an assertion fails.
+      m_treeviewcolumn_button->set_fixed_width(button_width);
 
     m_treeviewcolumn_button->set_visible(m_allow_view_details);
 
@@ -1053,7 +1110,11 @@ void DbAddDel::construct_specified_columns()
   #endif //GLOM_ENABLE_MAEMO
 
   bool no_columns_used = true;
-  int data_model_column_index = 0;
+  int data_model_column_index = 0; //-1 means undefined index.
+  
+  guint column_to_expand = 0;
+  const bool has_expandable_column = get_column_to_expand(column_to_expand);
+  //std::cout << "DEBUG: column_to_expand=" << column_to_expand  << ", has=" << has_expandable_column << std::endl;
   
   for(type_vecModelColumns::iterator iter = vecModelColumns.begin(); iter != vecModelColumns.end(); ++iter)
   {
@@ -1081,7 +1142,12 @@ void DbAddDel::construct_specified_columns()
       if(pCellRenderer)
       {
         //Get the index of the field in the query, if it is a field:
-        treeview_append_column(column_name, *pCellRenderer, model_column_index, item_data_model_column_index);
+        //std::cout << "debug: model_column_index=" << model_column_index << ", item_data_model_column_index=" << item_data_model_column_index << std::endl;
+        const bool expand = has_expandable_column && ((int)column_to_expand == model_column_index);
+        treeview_append_column(column_name, 
+          *pCellRenderer, 
+          model_column_index, item_data_model_column_index, 
+          expand);
 
         if(column_info.m_editable)
         {
@@ -1117,6 +1183,8 @@ void DbAddDel::construct_specified_columns()
     #endif //GLOM_ENABLE_MAEMO
   }
 
+  
+
   #ifndef GLOM_ENABLE_MAEMO
   m_TreeView.columns_autosize();
   #endif
@@ -1204,6 +1272,7 @@ void DbAddDel::remove_all_columns()
 {
   m_ColumnTypes.clear();
 
+  m_fixed_cell_height = 0; //Force it to be recalculated.
   m_columns_ready = false;
 }
 
@@ -1421,13 +1490,6 @@ void DbAddDel::set_allow_only_one_related_record(bool val)
   m_allow_only_one_related_record = val;
 }
 
-
-void DbAddDel::set_column_width(guint /* col */, guint /*width*/)
-{
-//  if( col < (guint)m_Sheet.get_columns_count())
-//    m_Sheet.set_column_width(col, width);
-}
-
 void DbAddDel::finish_editing()
 {
 //  bool bIgnoreSheetSignals = get_ignore_treeview_signals(); //The deactivate signals seems to cause the current cell to revert to it's previsous value.
@@ -1819,6 +1881,10 @@ void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColu
 {
   if(!view_column)
     return;
+  
+  //Ignore this property change signal handler if we are setting the size in code:
+  if(m_bIgnoreTreeViewSignals)
+    return;
 
   //We do not save the column width if this is the last column, 
   //because that must always be automatic, 
@@ -1830,9 +1896,12 @@ void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColu
 
   DbAddDelColumnInfo& column_info = m_ColumnTypes[model_column_index];
 
-  const guint width = (guint)view_column->get_width();
+  const int width = view_column->get_width();
   //std::cout << "  DbAddDel::on_treeview_column_resized(): width=" << width << std::endl;
 
+  if(width == -1) //Means automatic.
+    return;
+    
   if(column_info.m_item)
       column_info.m_item->set_display_width(width);
 }
@@ -1896,16 +1965,62 @@ void DbAddDel::on_treeview_columns_changed()
 }
 #endif //GLOM_ENABLE_MAEMO
 
-guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index)
+bool DbAddDel::get_column_to_expand(guint& column_to_expand) const
 {
-  #ifndef GLOM_ENABLE_MAEMO
+  //Initialize output parameter:
+  column_to_expand = 0;
+  bool result = false;
+  
+  //Discover the right-most text column: 
+  guint i = 0;
+  for(type_ColumnTypes::const_iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
+  {
+    sharedptr<LayoutItem> layout_item = iter->m_item;
+           
+    sharedptr<LayoutItem_Field> layout_item_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+    if(layout_item_field)
+    {  
+      //Only text columns should expand.
+      //Number fields are right-aligned, so expansion is annoying.
+      //Time and date fields don't vary their width much.
+      if(layout_item_field->get_glom_type() == Field::TYPE_TEXT)
+      {
+        //Check that no specific width has been specified:
+        const guint column_width = layout_item_field->get_display_width();
+        if(!column_width) //TODO: Ignore these on maemo?
+        {
+          column_to_expand = i;
+          result = true;
+        }
+        
+      }
+    }
+    
+    ++i;
+  }
+  
+  return result;
+}
+
+guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index, bool expand)
+{
+  InnerIgnore innerIgnore(this); //see comments for InnerIgnore class
+
+  #ifndef GLOM_ENABLE_MAEMO 
   DbTreeViewColumnGlom* pViewColumn = Gtk::manage( new DbTreeViewColumnGlom(Utils::string_escape_underscores(title), cellrenderer) );
-  pViewColumn->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED); //Need by fixed-height mode.
+
+  //This is needed by fixed-height mode. We get critical warnings otherwise.
+  //But we must call set_fixed_width() later or we will have a zero-width column.
+  pViewColumn->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
 
   guint cols_count = m_TreeView.append_column(*pViewColumn);
   #else
+  //Mathias Hasselmann says that this is required for the Maemo 5 style, 
+  //though we don't know yet where that is documented. murrayc.
+  cellrenderer.set_property("xpad", HILDON_MARGIN_DEFAULT);
+
   Glib::RefPtr<Hildon::TouchSelectorColumn> pViewColumn = touch_selector_get_column();
-  pViewColumn->pack_start(cellrenderer, false);
+  pViewColumn->pack_start(cellrenderer, expand);
   g_assert(pViewColumn);
   guint cols_count = get_columns_count();
   #endif //GLOM_ENABLE_MAEMO
@@ -1928,26 +2043,39 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
   pViewColumn->set_resizable();
   #endif //GLOM_ENABLE_MAEMO
   
-  guint column_width = 0;
-  if(!layout_item->get_display_width(column_width))
+  #ifndef GLOM_ENABLE_MAEMO
+  //GtkTreeView's fixed-height-mode does not allow us to have anything but 
+  //the last column as expandable.
+  //TODO: Can we get the total size and calculate a starting size instead?
+  expand = false;
+  #endif
+
+  int column_width = -1; //Means expand.
+  if(!expand)
   {
-    //TODO: Choose a width based on the first 100 values.
-    if(layout_item_field)
+    column_width = layout_item->get_display_width();
+    if(!(column_width > 0))
     {
-     column_width = Utils::get_suitable_field_width_for_widget(*this, layout_item_field);
-     column_width = column_width / 3;
-     //std::cout << "DEBUG: column_width=" << column_width << std::endl;
+      //TODO: Choose a width based on the first 100 values.
+      if(layout_item_field)
+      {
+       column_width = Utils::get_suitable_field_width_for_widget(*this, layout_item_field, true /* or_title */);
+       column_width = column_width / 3;
+       //std::cout << "DEBUG: column_width=" << column_width << std::endl;
+      }
+      else
+        column_width = 100; //TODO: Don't save this default in the document.
     }
-    else
-     column_width = 100;
   }
 
   #ifdef GLOM_ENABLE_MAEMO
-  cellrenderer.set_property("width", (int)column_width);
+  cellrenderer.set_property("width", column_width);
   #else
-  pViewColumn->set_fixed_width((int)column_width); //This is the only way to set the width, so we need to set it as resizable again immediately afterwards.
+  if(column_width > 0) //Otherwise there's an assertion fails.
+    pViewColumn->set_fixed_width(column_width); //This is the only way to set the width, so we need to set it as resizable again immediately afterwards.
+    
   pViewColumn->set_resizable();
-  //This property is read only: pViewColumn->property_width() = (int)column_width;
+  //This property is read only: pViewColumn->property_width() = column_width;
 
   //Save the extra ID, using the title if the column_id is empty:
   const Glib::ustring column_id = m_ColumnTypes[model_column_index].m_item->get_name();
@@ -2149,7 +2277,8 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
          std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"" << std::endl; 
       */
 
-      switch(field->get_glom_type())
+      const Field::glom_field_type type = field->get_glom_type();
+      switch(type)
       {
         case(Field::TYPE_BOOLEAN):
         {
@@ -2170,7 +2299,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
             if(pixbuf)
               pixbuf = ImageGlom::scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
 
-            g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : NULL, (gpointer)NULL);
+            g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : 0, (gpointer)0);
           }
           else
             g_warning("Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY");
@@ -2186,7 +2315,18 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
             //std::cout << "  debug: DbAddDel::treeviewcolumn_on_cell_data(): field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
             const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
             //g_assert(text != "NULL");
-            g_object_set(pDerived->gobj(), "text", text.c_str(), (gpointer)NULL);
+            g_object_set(pDerived->gobj(), "text", text.c_str(), (gpointer)0);
+          }
+
+          //Show a different color if the value is numeric, if that's specified:
+          if(type == Field::TYPE_NUMERIC)
+          {
+             const Glib::ustring fg_color = 
+               field->get_formatting_used().get_text_format_color_foreground_to_use(value);
+             if(!fg_color.empty())
+                 g_object_set(pDerived->gobj(), "foreground", fg_color.c_str(), (gpointer)0);
+             else
+                 g_object_set(pDerived->gobj(), "foreground", (const char*)0, (gpointer)0);
           }
 
           break;
@@ -2481,6 +2621,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   std::cout << "DEBUG: DbAddDel::user_added()" << std::endl;
 
   //Prevent impossible multiple related records:
+  //The developer-mode UI now prevents the developer from using such a relationship anyway.
   if(m_allow_only_one_related_record && (get_count() > 0))
   {
     //Tell user that they can't do that:
@@ -2496,7 +2637,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
 
   Gnome::Gda::Value primary_key_value;
 
-  sharedptr<Field> primary_key_field = get_key_field();
+  sharedptr<const Field> primary_key_field = get_key_field();
 
   //Get the new primary key value, if one is available now:
   if(primary_key_field->get_auto_increment())
@@ -2517,59 +2658,60 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   }
 
   //If no primary key value is available yet, then don't add the record yet:
-  if(!Conversions::value_is_empty(primary_key_value))
-  {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application()); //Keep it alive while we need the data_model.
-#else
-    std::auto_ptr<ExceptionConnection> error;
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application(), error); //Keep it alive while we need the data_model.
-    // Ignore error - sharedconnection is checked for NULL instead:
-#endif
-    if(sharedconnection)
-    {
-      sharedptr<LayoutItem_Field> layout_field = sharedptr<LayoutItem_Field>::create();
-      layout_field->set_full_field_details(primary_key_field);
-      if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, layout_field, primary_key_value, get_application()))
-      {
-        //Revert to a blank value.
-        primary_key_value = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
-        set_entered_field_data(row, layout_field, primary_key_value);
-        return;
-      }
-
-      if(m_find_mode)
-        return;
+  if(Conversions::value_is_empty(primary_key_value))
+    return;
     
-      const bool added = record_new(true /* use entered field data*/, primary_key_value);
-      if(added)
-      {
-        //Save the primary key value for later use:
-        set_value_key(row, primary_key_value);
-
-        //Show the primary key in the row, if the primary key is visible:
-
-        //If it's an auto-increment, then get the value and show it:
-        if(primary_key_field->get_auto_increment())
-        {
-          sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-          layout_item->set_full_field_details(primary_key_field);
-          set_value(row, layout_item, primary_key_value);
-        }
-
-        //Allow a parent widget to link the new record by setting the foreign key:
-        signal_record_added().emit(row, primary_key_value);
-      }
-      else
-        handle_error();
-    }
-    else
-    {
-      //Add Record failed.
-      //Replace with correct values:
-      fill_from_database();
-    }
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application()); //Keep it alive while we need the data_model.
+  #else
+  std::auto_ptr<ExceptionConnection> error;
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application(), error); //Keep it alive while we need the data_model.
+  // Ignore error - sharedconnection is checked for NULL instead:
+  #endif
+  if(!sharedconnection)
+  {
+    //Add Record failed.
+    //Replace with correct values:
+    fill_from_database();
+    return;
   }
+  
+
+  sharedptr<LayoutItem_Field> layout_field = sharedptr<LayoutItem_Field>::create();
+  layout_field->set_full_field_details(primary_key_field);
+  if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, layout_field, primary_key_value, get_application()))
+  {
+    //Revert to a blank value.
+    primary_key_value = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
+    set_entered_field_data(row, layout_field, primary_key_value);
+    return;
+  }
+
+  if(m_find_mode)
+    return;
+
+  const bool added = record_new(true /* use entered field data*/, primary_key_value);
+  if(!added)
+  {
+    handle_error();
+    return;
+  }
+  
+  //Save the primary key value for later use:
+  set_value_key(row, primary_key_value);
+
+  //Show the primary key in the row, if the primary key is visible:
+
+  //If it's an auto-increment, then get the value and show it:
+  if(primary_key_field->get_auto_increment())
+  {
+    sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+    layout_item->set_full_field_details(primary_key_field);
+    set_value(row, layout_item, primary_key_value);
+  }
+
+  //Allow a parent widget to link the new record by setting the foreign key:
+  signal_record_added().emit(row, primary_key_value);
 }
 
 void DbAddDel::user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator&  /* rowEnd TODO */)
