@@ -35,7 +35,12 @@ namespace Glom
 {
 
 EntryGlom::EntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::Entry(cobject),
+:
+#ifdef GLOM_ENABLE_MAEMO
+  Hildon::Entry(cobject),
+#else
+  Gtk::Entry(cobject),
+#endif
   m_glom_type(Field::TYPE_TEXT)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -45,7 +50,11 @@ EntryGlom::EntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
 }
 
 EntryGlom::EntryGlom(Field::glom_field_type glom_type)
-: m_glom_type(glom_type)
+:
+#ifdef GLOM_ENABLE_MAEMO
+  Hildon::Entry(Gtk::Hildon::SIZE_AUTO),
+#endif
+ m_glom_type(glom_type)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_menu();
@@ -60,23 +69,30 @@ EntryGlom::~EntryGlom()
 
 void EntryGlom::init()
 {
-  if(m_glom_type == Field::TYPE_NUMERIC)
-    set_alignment(1.0); //Align numbers to the right.
-
 #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   signal_focus_out_event().connect(sigc::mem_fun(*this, &EntryGlom::on_focus_out_event));
   signal_activate().connect(sigc::mem_fun(*this, &EntryGlom::on_activate));
   signal_changed().connect(sigc::mem_fun(*this, &EntryGlom::on_changed));
-  signal_insert_text().connect(sigc::mem_fun(*this, &EntryGlom::on_insert_text));
 #endif // !GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 }
 
 void EntryGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
 {
   LayoutWidgetField::set_layout_item(layout_item, table_name);
-#ifndef GLOM_ENABLE_MAEMO  
+#ifdef GTKMM_ATKMM_ENABLED
   get_accessible()->set_name(layout_item->get_name());
-#endif  
+#endif
+
+  //Horizontal Alignment:
+  FieldFormatting::HorizontalAlignment alignment = 
+    FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT;
+  sharedptr<LayoutItem_Field> layout_field =
+    sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  if(layout_field)
+    alignment = layout_field->get_formatting_used_horizontal_alignment();
+
+  const float x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
+  set_alignment(x_align);
 }
 
 void EntryGlom::set_glom_type(Field::glom_field_type glom_type)
@@ -115,12 +131,14 @@ void EntryGlom::check_for_change()
   }
 }
 
+#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 bool EntryGlom::on_focus_out_event(GdkEventFocus* event)
 {
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  bool result = Gtk::Entry::on_focus_out_event(event);
+  const bool result = Gtk::Entry::on_focus_out_event(event);
 #else
-  bool result = false;
+bool EntryGlom::on_focus_out_event(GdkEventFocus* /* event */)
+{
+  const bool result = false;
 #endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 
   //The user has finished editing.
@@ -151,22 +169,24 @@ void EntryGlom::on_changed()
 #endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 }
 
-void EntryGlom::on_insert_text(const Glib::ustring& text, int* position)
-{
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  Gtk::Entry::on_insert_text(text, position);
-#endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-}
-
 void EntryGlom::set_value(const Gnome::Gda::Value& value)
 {
   sharedptr<const LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
-  if(layout_item)
-  {
-    const Glib::ustring text = Conversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format);
-    set_text(text);
+  if(!layout_item)
+    return;
 
-    //std::cout << "debug: EntryGlom::set_value(): name=" << layout_item->get_name() << ", text=" << text << std::endl;
+  const Glib::ustring text = Conversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format);
+  set_text(text);
+
+  //Show a different color if the value is numeric, if that's specified:
+  if(layout_item->get_glom_type() == Field::TYPE_NUMERIC)
+  {
+    const Glib::ustring fg_color = 
+    layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
+    if(!fg_color.empty())
+      modify_text(Gtk::STATE_NORMAL, Gdk::Color(fg_color));
+    else
+      modify_text(Gtk::STATE_NORMAL, Gdk::Color());
   }
 }
 
